@@ -1,10 +1,4 @@
 package Dist::Zilla::PluginBundle::GENEHACK;
-BEGIN {
-  $Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.03';
-}
-BEGIN {
-  $Dist::Zilla::PluginBundle::GENEHACK::AUTHORITY = 'cpan:GENEHACK';
-}
 # ABSTRACT: BeLike::GENEHACK when you zilla your dist
 
 
@@ -27,6 +21,7 @@ use Dist::Zilla::Plugin::GitFmtChanges;
 use Dist::Zilla::Plugin::Git::NextVersion;
 use Dist::Zilla::Plugin::Homepage;
 use Dist::Zilla::Plugin::InstallGuide;
+use Dist::Zilla::Plugin::InstallRelease;
 use Dist::Zilla::Plugin::KwaliteeTests;
 use Dist::Zilla::Plugin::MetaConfig;
 use Dist::Zilla::Plugin::MetaJSON;
@@ -126,6 +121,8 @@ sub configure {
   $self->add_plugins(
     # tweet releases. because i can.
     'Twitter' ,
+    # install dist after release
+    [ 'InstallRelease' => { install_command => 'cpanm .' } ] ,
   );
 
   ## PLUGINS WHAT NEED TO LOAD LATER THAN OTHERS
@@ -149,7 +146,7 @@ Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -186,6 +183,7 @@ this:
     [KwaliteeTests]
     [Twitter]
     [ArchiveRelease]
+    [InstallRelease]
 
 =for Pod::Coverage configure
 
